GpuTransformId

Struct GpuTransformId 

#[repr(C)]
pub struct GpuTransformId(pub u32);
Represents the information about a transform palette entry that is passed to shaders. It includes an index into the transform palette, and a set of flags.

Tuple Fields

0: u32

Implementations

Source

impl GpuTransformId

pub const IDENTITY: Self

Identity transform ID.

const INDEX_MASK: u32 = 0x003fffff

const AXIS_ALIGNED_2D_BIT: u32

if not set, the transform is axis-aligned.

const SCALE_OFFSET_2D_BIT: u32

If not set, the transform can be represented as a 2d scale + offset.

pub fn transform_kind(&self) -> TransformedRectKind

Extract the transform kind from the id.

pub fn is_2d_axis_aligned(&self) -> bool

Note: There are transformations that preserve axis-alignment without being scale + offsets.

pub fn is_2d_scale_offset(&self) -> bool

Returns true if the transform can be represented by a 2d scale + offset.

pub fn metadata(&self) -> TransformMetadata

pub fn override_transform_kind(&self, kind: TransformedRectKind) -> Self

Override the kind of transform stored in this id. This can be useful in cases where we don’t want shaders to consider certain transforms axis- aligned (i.e. perspective warp) even though we may still want to for the general case.